﻿using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;

namespace Falcon.SugarApi.TimedTask.TaskManager
{
    /// <summary>
    /// 任务管理接口
    /// </summary>
    public interface ITaskManager
    {
        /// <summary>
        /// 任务名称
        /// </summary>
        string TaskName { get; }
        /// <summary>
        /// 任务说明
        /// </summary>
        string TaskDesc { get; }
        /// <summary>
        /// 任务计划
        /// </summary>
        string TaskSchedule { get; }
        /// <summary>
        /// 任务分组
        /// </summary>
        string? TaskGroup { get; }

        /// <summary>
        /// 运行一次任务
        /// </summary>
        /// <param name="cancellationToken">退出信号</param>
        /// <returns>控制结果</returns>
        Task<TaskControlResult> RunOnceAsync(CancellationToken cancellationToken = default);
        /// <summary>
        /// 开始任务
        /// </summary>
        /// <param name="cancellationToken">退出信号</param>
        /// <returns>控制结果</returns>
        Task<TaskControlResult> StartTaskAsync(CancellationToken cancellationToken = default);
        /// <summary>
        /// 停止任务
        /// </summary>
        /// <param name="cancellationToken">退出信号</param>
        /// <returns>控制结果</returns>
        Task<TaskControlResult> StopTaskAsync(CancellationToken cancellationToken = default);

        /// <summary>
        /// 获得当前任务状态
        /// </summary>
        /// <returns>当前任务状态</returns>
        Task<TaskState> GetTaskStateAsync(CancellationToken cancellationToken = default);
        /// <summary>
        /// 获取任务明细
        /// </summary>
        /// <param name="cancellationToken">退出信号</param>
        /// <returns>任务明细</returns>
        Task<TaskDetailStatus> GetTaskDetailStatus(CancellationToken cancellationToken = default);
        /// <summary>
        /// 获取运行日志
        /// </summary>
        /// <param name="take">获取日志的数量</param>
        /// <param name="skip">跳过的日志数量</param>
        /// <param name="cancellationToken">任务退出信号</param>
        /// <returns>任务日志列表</returns>
        Task<List<LastRunInformation>> GetRunLogsAsync(int take = 10,int skip = 0,CancellationToken cancellationToken = default);
    }
}
